@@ -5,9 +5,9 @@ use strict;
 use utf8;
 use Carp;
 
-our $VERSION = 'v0.2.3';
+our $VERSION = 'v0.2.4';
 
-use Perl6::Export::Attrs;
+use Export::Attrs;
 use Scalar::Util qw( weaken refaddr blessed );
 
 
@@ -364,8 +364,7 @@ Sub::Throttler - Rate limit sync and async function calls
 
 =head1 VERSION
 
-This document describes Sub::Throttler version v0.2.3
-
+This document describes Sub::Throttler version v0.2.4
 
 =head1 SYNOPSIS
 
@@ -991,4 +990,4 @@ This is free software, licensed under:
   The MIT (X11) License
 
 
-=cut
\ No newline at end of file
+=cut
